## Version:1.0.0 -- 4 June 2025

* Versioning for public plugin release

## Version:0.1.5 -- 27 May 2025

* Additional formatting for upload time statistics so text does not overflow

## Version:0.1.4 -- 27 May 2025

* Ensures multi-job submission data is accurate by populating the Manifest Queue at upload time

## Version:0.1.3 -- 16 May 2025

* Submit only enabled Movie Render Queue Jobs for rendering

## Version:0.1.2 -- 14 May 2025

*  Ensure render execution by filtering and submitting to only Windows instances

## Version:0.1.1 -- 21 Mar 2025

*  Supports plugin installation through the Conductor Companion App

## Version:0.1.0 -- 15 Jan 2025

*  Ensure Unreal render engine compatibility by only displaying single GPU instance types